kenchi\.outlier\_detection\.statistical module
==============================================

.. automodule:: kenchi.outlier_detection.statistical
    :members:
    :undoc-members:
    :show-inheritance:
